slice

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 20, 2022 License: Unlicense Imports: 0 Imported by: 0

Documentation

Overview

Package slice contains functions for making work with slices easier.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Deduplicate

func Deduplicate[T comparable](s []T) []T

Deduplicate returns a slice of the same comparable type with all duplicate values removed. Note that the order of elements *will not* be preserved.

Types

This section is empty.

Jump to