Documentation
¶
Overview ¶
Package slice contains functions for making work with slices easier.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Deduplicate ¶
func Deduplicate[T comparable](s []T) []T
Deduplicate returns a slice of the same comparable type with all duplicate values removed. Note that the order of elements *will not* be preserved.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.